is_timeout_error: Compare an error against a timeout error from setTimeLimit

Description Usage Arguments Value

View source: R/utils.R

Description

Compare an error against a timeout error from setTimeLimit

Usage

1

Arguments

e

an error to compare

Value

a logical indicating whether e is a setTimeLimit timeout error


dgkf/riddlr documentation built on Oct. 24, 2020, 3:52 a.m.