Description Usage Format Examples
Expects a function expecting arguments code, duration and
response. This function is called after a question solution is
submitted and graded and can be used as a callback for additional
functionality or logging.
1 |
An object of class list of length 2.
1 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.